'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ButtonGroup = exports.ButtonGroupColors = exports.ButtonGroupSizes = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _checkTypes = require('check-types');

var _checkTypes2 = _interopRequireDefault(_checkTypes);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _lodash = require('lodash.omit');

var _lodash2 = _interopRequireDefault(_lodash);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Button group size enumerable.
 *
 * @type {Object}
 */
var ButtonGroupSizes = exports.ButtonGroupSizes = {
  TINY: 'tiny',
  SMALL: 'small',
  LARGE: 'large'
};

/**
 * Button group color enumerable.
 *
 * @type {Object}
 */
var ButtonGroupColors = exports.ButtonGroupColors = {
  PRIMARY: 'primary',
  SECONDARY: 'secondary',
  SUCCESS: 'success',
  ALERT: 'alert',
  WARNING: 'warning'
};

/**
 * Button group component.
 * http://foundation.zurb.com/sites/docs/button-group.html
 *
 * @param {Object} props
 * @returns {XML}
 */
var ButtonGroup = exports.ButtonGroup = function ButtonGroup(props) {
  // TODO: Consider validating both size and color values.
  _checkTypes2.default.assert.maybe.string(props.size, 'ButtonGroup.props.size must be a string');
  _checkTypes2.default.assert.maybe.string(props.color, 'ButtonGroup.props.color must be a string');
  _checkTypes2.default.assert.maybe.boolean(props.isExpanded, 'ButtonGroup.props.isExpanded must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.isStacked, 'ButtonGroup.props.isStacked must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.stackOnSmall, 'ButtonGroup.props.stackOnSmall must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.stackOnMedium, 'ButtonGroup.props.stackOnMedium must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.stackOnLarge, 'ButtonGroup.props.stackOnLarge must be a boolean.');

  var className = (0, _classnames2.default)(props.className || 'button-group', props.size, props.color, {
    'expanded': props.isExpanded,
    'stacked': props.isStacked,
    'stacked-for-small': props.stackOnSmall,
    'stacked-for-medium': props.stackOnMedium,
    'stacked-for-large': props.stackOnLarge
  });

  var omitProps = ['size', 'color', 'isExpanded', 'isStacked', 'stackOnSmall', 'stackOnMedium', 'stackOnLarge'];

  return _react2.default.createElement('div', _extends({}, (0, _lodash2.default)(props, omitProps), { className: className }));
};

exports.default = ButtonGroup;