'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Link = exports.Button = exports.ButtonColors = exports.ButtonSizes = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _checkTypes = require('check-types');

var _checkTypes2 = _interopRequireDefault(_checkTypes);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _lodash = require('lodash.omit');

var _lodash2 = _interopRequireDefault(_lodash);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Button size enumerable.
 *
 * @type {Object}
 */
var ButtonSizes = exports.ButtonSizes = {
  TINY: 'tiny',
  SMALL: 'small',
  LARGE: 'large'
};

/**
 * Button color enumerable.
 *
 * @type {Object}
 */
var ButtonColors = exports.ButtonColors = {
  PRIMARY: 'primary',
  SECONDARY: 'secondary',
  SUCCESS: 'success',
  ALERT: 'alert',
  WARNING: 'warning'
};

var omitProps = ['color', 'size', 'isHollow', 'isExpanded', 'isDisabled', 'isDropdown', 'isArrowOnly'];

/**
 * Button component.
 * http://foundation.zurb.com/sites/docs/button.html
 *
 * @param {Object} props
 * @returns {XML}
 */
var Button = exports.Button = function Button(props) {
  return _react2.default.createElement('button', _extends({}, (0, _lodash2.default)(props, omitProps), { className: classNameFromProps(props) }));
};

/**
 * Link button component.
 * http://foundation.zurb.com/sites/docs/button.html#basics
 *
 * @param {Object} props
 * @returns {XML}
 */
var Link = exports.Link = function Link(props) {
  return _react2.default.createElement('a', _extends({}, (0, _lodash2.default)(props, omitProps), { className: classNameFromProps(props) }));
};

/**
 * Creates the button class name from the given properties.
 * This method allows us to share code between the `Button` and `Link` components.
 *
 * @param {Object} props
 * @returns {string}
 */
function classNameFromProps(props) {
  // TODO: Consider validating both size and color values.
  _checkTypes2.default.assert.maybe.string(props.size, 'Button.props.size must be a string.');
  _checkTypes2.default.assert.maybe.string(props.color, 'Button.props.color must be a string.');
  _checkTypes2.default.assert.maybe.boolean(props.isHollow, 'Button.props.isHollow must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.isExpanded, 'Button.props.isExpanded must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.isDisabled, 'Button.props.isDisabled must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.isDropdown, 'Button.props.isDropdown must be a boolean.');

  return (0, _classnames2.default)(props.className || 'button', props.size, props.color, {
    'hollow': props.isHollow,
    'expanded': props.isExpanded,
    'disabled': props.isDisabled,
    'dropdown': props.isDropdown,
    'arrow-only': props.isArrowOnly
  });
}

exports.default = Button;