'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Callout = exports.CalloutSizes = exports.CalloutColors = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _checkTypes = require('check-types');

var _checkTypes2 = _interopRequireDefault(_checkTypes);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _lodash = require('lodash.omit');

var _lodash2 = _interopRequireDefault(_lodash);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Callout color enumerable.
 *
 * @type {Object}
 */
var CalloutColors = exports.CalloutColors = {
  PRIMARY: 'primary',
  SECONDARY: 'secondary',
  SUCCESS: 'success',
  WARNING: 'warning',
  ALERT: 'alert'
};

/**
 * Callout size enumerable.
 *
 * @type {Object}
 */
var CalloutSizes = exports.CalloutSizes = {
  SMALL: 'small',
  LARGE: 'large'
};

/**
 * Callout component.
 * http://foundation.zurb.com/sites/docs/callout.html
 *
 * @param {Object} props
 * @returns {XML}
 */
var Callout = exports.Callout = function Callout(props) {
  _checkTypes2.default.assert.maybe.string(props.color, 'Callout.props.color must be a string.');
  _checkTypes2.default.assert.maybe.string(props.size, 'Callout.props.size must be a string.');

  var className = (0, _classnames2.default)(props.className || 'callout', props.color, props.size);

  var omitProps = ['color', 'size'];

  return _react2.default.createElement('div', _extends({}, (0, _lodash2.default)(props, omitProps), { className: className }));
};

// TODO: Add support for closable elements.

exports.default = Callout;