'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Column = exports.Row = exports.RowVerticalAlignments = exports.RowHorizontalAlignments = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _checkTypes = require('check-types');

var _checkTypes2 = _interopRequireDefault(_checkTypes);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _lodash = require('lodash.has');

var _lodash2 = _interopRequireDefault(_lodash);

var _lodash3 = require('lodash.omit');

var _lodash4 = _interopRequireDefault(_lodash3);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Row horizontal alignments enumerable.
 *
 * @type {Object}
 */
var RowHorizontalAlignments = exports.RowHorizontalAlignments = {
  RIGHT: 'right',
  CENTER: 'center',
  JUSTIFY: 'justify',
  SPACED: 'spaced'
};

/**
 * Row vertical alignments enumerable.
 *
 * @type {Object}
 */
var RowVerticalAlignments = exports.RowVerticalAlignments = {
  TOP: 'top',
  MIDDLE: 'middle',
  BOTTOM: 'bottom',
  STRETCH: 'stretch'
};

/**
 * Row component.
 *
 * @param {Object} props
 * @returns {XML}
 */
var Row = exports.Row = function Row(props) {
  _checkTypes2.default.assert.maybe.string(props.horizontalAlignment, 'Row.props.horizontalAlignment must be a string.');
  _checkTypes2.default.assert.maybe.string(props.verticalAlignment, 'Row.props.verticalAlignment must be a string.');
  _checkTypes2.default.assert.maybe.boolean(props.unstackOnSmall, 'Row.props.unstackOnSmall must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.unstackOnMedium, 'Row.props.unstackOnMedium must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.unstackOnLarge, 'Row.props.unstackOnLarge must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.isColumn, 'Row.props.isColumn must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.isExpanded, 'Row.props.isExpanded must be a boolean.');

  var className = (0, _classnames2.default)(props.className || 'row', {
    'align-right': props.horizontalAlignment === RowHorizontalAlignments.RIGHT,
    'align-center': props.horizontalAlignment === RowHorizontalAlignments.CENTER,
    'align-justify': props.horizontalAlignment === RowHorizontalAlignments.JUSTIFY,
    'align-spaced': props.horizontalAlignment === RowHorizontalAlignments.SPACED,
    'align-top': props.verticalAlignment === RowVerticalAlignments.TOP,
    'align-middle': props.verticalAlignment === RowVerticalAlignments.MIDDLE,
    'align-bottom': props.verticalAlignment === RowVerticalAlignments.BOTTOM,
    'align-stretch': props.verticalAlignment === RowVerticalAlignments.STRETCH,
    'small-unstack': props.unstackOnSmall,
    'medium-unstack': props.unstackOnMedium,
    'large-unstack': props.unstackOnLarge,
    'column': props.isColumn,
    'expanded': props.isExpanded
  });

  var omitProps = ['horizontalAlignment', 'verticalAlignment', 'unstackOnSmall', 'unstackOnMedium', 'unstackOnLarge', 'column', 'isExpanded'];

  return _react2.default.createElement('div', _extends({}, (0, _lodash4.default)(props, omitProps), { className: className }));
};

/**
 * Column component.
 *
 * @param {Object} props
 * @returns {XML}
 */
var Column = exports.Column = function Column(props) {
  _checkTypes2.default.assert.maybe.number(props.small, 'Column.props.small must be a number.');
  _checkTypes2.default.assert.maybe.number(props.medium, 'Column.props.medium must be a number.');
  _checkTypes2.default.assert.maybe.number(props.large, 'Column.props.large must be a number.');
  _checkTypes2.default.assert.maybe.object(props.offset, 'Column.props.offset must be an object.');
  _checkTypes2.default.assert.maybe.object(props.push, 'Column.props.push must be an object.');
  _checkTypes2.default.assert.maybe.object(props.pull, 'Column.props.pull must be an object.');
  _checkTypes2.default.assert.maybe.object(props.up, 'Column.props.up must be an object.');
  _checkTypes2.default.assert.maybe.object(props.order, 'Column.props.order must be an object.');
  _checkTypes2.default.assert.maybe.boolean(props.collapseOnSmall, 'Column.props.collapseOnSmall must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.collapseOnMedium, 'Column.props.collapseOnMedium must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.collapseOnLarge, 'Column.props.collapseOnLarge must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.uncollapseOnSmall, 'Column.props.uncollapseOnSmall must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.uncollapseOnMedium, 'Column.props.uncollapseOnMedium must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.uncollapseOnLarge, 'Column.props.uncollapseOnLarge must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.centerOnSmall, 'Column.props.centerOnSmall must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.centerOnMedium, 'Column.props.centerOnMedium must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.centerOnLarge, 'Column.props.centerOnLarge must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.uncenterOnSmall, 'Column.props.uncenterOnSmall must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.uncenterOnMedium, 'Column.props.uncenterOnMedium must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.uncenterOnLarge, 'Column.props.uncenterOnLarge must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.expandOnSmall, 'Column.props.expandOnSmall must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.expandOnMedium, 'Column.props.expandOnMedium must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.expandOnLarge, 'Column.props.expandOnLarge must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.shrink, 'Column.props.shrink must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.isLast, 'Column.props.isLast must be a boolean.');

  var className = (0, _classnames2.default)(props.className || 'columns', props.small ? 'small-' + props.small : null, props.medium ? 'medium-' + props.medium : null, props.large ? 'large-' + props.large : null, (0, _lodash2.default)(props, 'offset.small') ? 'small-offset-' + props.offset.small : null, (0, _lodash2.default)(props, 'offset.medium') ? 'medium-offset-' + props.offset.medium : null, (0, _lodash2.default)(props, 'offset.large') ? 'large-offset-' + props.offset.large : null, (0, _lodash2.default)(props, 'push.small') ? 'small-push-' + props.push.small : null, (0, _lodash2.default)(props, 'push.medium') ? 'medium-push-' + props.push.medium : null, (0, _lodash2.default)(props, 'push.large') ? 'large-push-' + props.push.large : null, (0, _lodash2.default)(props, 'pull.small') ? 'small-pull-' + props.pull.small : null, (0, _lodash2.default)(props, 'pull.medium') ? 'medium-pull-' + props.pull.medium : null, (0, _lodash2.default)(props, 'pull.large') ? 'large-pull-' + props.pull.large : null, (0, _lodash2.default)(props, 'up.small') ? 'small-up-' + props.up.small : null, (0, _lodash2.default)(props, 'up.medium') ? 'medium-up-' + props.up.medium : null, (0, _lodash2.default)(props, 'up.large') ? 'large-up-' + props.up.large : null, (0, _lodash2.default)(props, 'order.small') ? 'small-order-' + props.order.small : null, (0, _lodash2.default)(props, 'order.medium') ? 'medium-order-' + props.order.medium : null, (0, _lodash2.default)(props, 'order.large') ? 'large-order-' + props.order.large : null, {
    'collapse-small': props.collapseOnSmall,
    'collapse-medium': props.collapseOnMedium,
    'collapse-large': props.collapseOnLarge,
    'uncollapse-small': props.uncollapseOnSmall,
    'uncollapse-medium': props.uncollapseOnMedium,
    'uncollapse-large': props.uncollapseOnLarge,
    'small-centered': props.centerOnSmall,
    'medium-centered': props.centerOnMedium,
    'large-centered': props.centerOnLarge,
    'small-uncentered': props.uncenterOnSmall,
    'medium-uncentered': props.uncenterOnMedium,
    'large-uncentered': props.uncenterOnLarge,
    'small-expand': props.expandOnSmall,
    'medium-expand': props.expandOnMedium,
    'large-expand': props.expandOnLarge,
    'shrink': props.shrink,
    'end': props.isLast
  });

  var omitProps = ['small', 'medium', 'large', 'offset', 'push', 'pull', 'up', 'order', 'collapseOnSmall', 'collapseOnMedium', 'collapseOnLarge', 'uncollapseOnSmall', 'uncollapseOnMedium', 'uncollapseOnLarge', 'centerOnSmall', 'centerOnMedium', 'centerOnLarge', 'uncenterOnSmall', 'uncenterOnMedium', 'uncenterOnLarge', 'expandOnSmall', 'expandOnMedium', 'expandOnLarge', 'shrink', 'isLast'];

  return _react2.default.createElement('div', _extends({}, (0, _lodash4.default)(props, omitProps), { className: className }));
};