'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.MediaObjectSection = exports.MediaObject = exports.MediaObjectSectionAlignments = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _checkTypes = require('check-types');

var _checkTypes2 = _interopRequireDefault(_checkTypes);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _lodash = require('lodash.omit');

var _lodash2 = _interopRequireDefault(_lodash);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Media object section alignment enumerable.
 *
 * @type {{RIGHT: string, CENTER: string, JUSTIFY: string, SPACED: string}}
 */
var MediaObjectSectionAlignments = exports.MediaObjectSectionAlignments = {
  RIGHT: 'right',
  CENTER: 'center',
  JUSTIFY: 'justify',
  SPACED: 'spaced'
};

/**
 * Media object component.
 *
 * @param {{stackOnSmall: boolean}} props
 * @returns {JSX}
 */
var MediaObject = exports.MediaObject = function MediaObject(props) {
  _checkTypes2.default.assert.maybe.boolean(props.stackOnSmall, 'MediaObject.props.stackOnSmall must be a boolean.');

  var className = (0, _classnames2.default)(props.className || 'media-object', {
    'stack-for-small': props.stackOnSmall
  });

  var omitProps = ['stackOnSmall'];

  return _react2.default.createElement('div', _extends({}, (0, _lodash2.default)(props, omitProps), { className: className }));
};

/**
 * Media object section component.
 *
 * @param {{alignment: [string], isMain: boolean, isMiddle: boolean}} props
 * @returns {JSX}
 */
var MediaObjectSection = exports.MediaObjectSection = function MediaObjectSection(props) {
  _checkTypes2.default.assert.maybe.string(props.alignment, 'MediaObject.props.alignment must be a string.');
  _checkTypes2.default.assert.maybe.boolean(props.isMain, 'MediaObject.props.isMain must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.isMiddle, 'MediaObject.props.isMiddle must be a boolean.');

  var className = (0, _classnames2.default)(props.className || 'media-object-section', {
    'align-self-center': props.alignment === MediaObjectSectionAlignments.CENTER,
    'align-self-right': props.alignment === MediaObjectSectionAlignments.RIGHT,
    'align-self-justify': props.alignment === MediaObjectSectionAlignments.JUSTIFY,
    'align-self-spaced': props.alignment === MediaObjectSectionAlignments.SPACED,
    'main-section': props.isMain,
    'middle': props.isMiddle
  });

  var omitProps = ['alignment', 'isMain', 'isMiddle'];

  return _react2.default.createElement('div', _extends({}, (0, _lodash2.default)(props, omitProps), { className: className }));
};