'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.MenuText = exports.MenuItem = exports.Menu = exports.MenuAlignments = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _checkTypes = require('check-types');

var _checkTypes2 = _interopRequireDefault(_checkTypes);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _lodash = require('lodash.omit');

var _lodash2 = _interopRequireDefault(_lodash);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Menu alignment enumerable.
 *
 * @type {Object}
 */
var MenuAlignments = exports.MenuAlignments = {
  RIGHT: 'right',
  CENTER: 'center'
};

/**
 * Menu component.
 * http://foundation.zurb.com/sites/docs/menu.html
 *
 * @param {Object} props
 * @returns {XML}
 */
var Menu = exports.Menu = function Menu(props) {
  _checkTypes2.default.assert.maybe.string(props.alignment, 'Menu.props.alignment must be a string.');
  _checkTypes2.default.assert.maybe.boolean(props.iconsOnTop, 'Menu.props.iconsOnTop must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.isExpanded, 'Menu.props.isExpanded must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.isVertical, 'Menu.props.isVertical must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.isSimple, 'Menu.props.isSimple must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.isNested, 'Menu.props.isNested must be a boolean.');

  var className = (0, _classnames2.default)(props.className || 'menu', {
    'align-right': props.alignment === MenuAlignments.RIGHT,
    'align-center': props.alignment === MenuAlignments.CENTER,
    'icon-top': props.iconsOnTop,
    'expanded': props.isExpanded,
    'vertical': props.isVertical,
    'simple': props.isSimple,
    'nested': props.isNested
  });

  var omitProps = ['alignment', 'iconsOnTop', 'isExpanded', 'isVertical', 'isSimple', 'isNested'];

  return _react2.default.createElement('ul', _extends({}, (0, _lodash2.default)(props, omitProps), { className: className }));
};

/**
 * Menu item component.
 *
 * @param {Object} props
 * @returns {XML}
 */
var MenuItem = exports.MenuItem = function MenuItem(props) {
  _checkTypes2.default.assert.maybe.boolean(props.isActive, 'MenuItem.props.isActive must be a boolean.');

  var className = (0, _classnames2.default)(props.className, {
    'active': props.isActive
  });

  var omitProps = ['isActive'];

  return _react2.default.createElement('li', _extends({}, (0, _lodash2.default)(props, omitProps), { className: className }));
};

/**
 * Menu text wrapper-component.
 *
 * @param {Object} props
 * @returns {XML}
 */
var MenuText = exports.MenuText = function MenuText(props) {
  return _react2.default.createElement(MenuItem, _extends({}, props, { className: props.className || 'menu-text' }));
};

exports.default = Menu;