'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.PaginationEllipsis = exports.PaginationNext = exports.PaginationPrevious = exports.PaginationItem = exports.Pagination = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _checkTypes = require('check-types');

var _checkTypes2 = _interopRequireDefault(_checkTypes);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _lodash = require('lodash.omit');

var _lodash2 = _interopRequireDefault(_lodash);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Pagination component.
 * http://foundation.zurb.com/sites/docs/pagination.html
 *
 * @param {Object} props
 * @returns {XML}
 */
var Pagination = exports.Pagination = function Pagination(props) {
  _checkTypes2.default.assert.maybe.boolean(props.isCentered, 'Pagination.props.isCentered must be a boolean.');

  var className = (0, _classnames2.default)(props.className || 'pagination', {
    'text-center': props.isCentered
  });

  var omitProps = ['isCentered'];

  return _react2.default.createElement('ul', _extends({}, (0, _lodash2.default)(props, omitProps), { className: className, role: 'navigation' }));
};

/**
 * Pagination item component.
 *
 * @param {Object} props
 * @returns {XML}
 */
var PaginationItem = exports.PaginationItem = function PaginationItem(props) {
  _checkTypes2.default.assert.maybe.boolean(props.isCurrent, 'PaginationItem.props.isCurrent must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.isDisabled, 'PaginationItem.props.isDisabled must be a boolean.');

  var className = (0, _classnames2.default)(props.className, {
    'current': props.isCurrent,
    'disabled': props.isDisabled
  });

  var omitProps = ['isCurrent', 'isDisabled'];

  return _react2.default.createElement('li', _extends({}, (0, _lodash2.default)(props, omitProps), { className: className }));
};

/**
 * Pagination previous wrapper-component.
 *
 * @param {Object} props
 * @returns {XML}
 */
var PaginationPrevious = exports.PaginationPrevious = function PaginationPrevious(props) {
  return _react2.default.createElement(PaginationItem, _extends({}, props, { className: props.className || 'pagination-previous' }));
};

/**
 * Pagination next wrapper-component.
 *
 * @param {Object} props
 * @returns {XML}
 */
var PaginationNext = exports.PaginationNext = function PaginationNext(props) {
  return _react2.default.createElement(PaginationItem, _extends({}, props, { className: props.className || 'pagination-next' }));
};

/**
 * Pagination ellipsis wrapper-component.
 *
 * @param {Object} props
 * @returns {XML}
 */
var PaginationEllipsis = exports.PaginationEllipsis = function PaginationEllipsis(props) {
  return _react2.default.createElement(PaginationItem, _extends({}, props, { className: props.className || 'ellipsis' }));
};

exports.default = Pagination;