'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.NativeProgress = exports.ProgressMeterText = exports.ProgressMeterWithText = exports.ProgressMeter = exports.Progress = exports.ProgressColors = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _checkTypes = require('check-types');

var _checkTypes2 = _interopRequireDefault(_checkTypes);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _lodash = require('lodash.omit');

var _lodash2 = _interopRequireDefault(_lodash);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var ProgressColors = exports.ProgressColors = {
  SECONDARY: 'secondary',
  SUCCESS: 'success',
  WARNING: 'warning',
  ALERT: 'alert'
};

/**
 * Progress component.
 * http://foundation.zurb.com/sites/docs/progress-bar.html
 *
 * @param {Object} props
 * @returns {XML}
 */
var Progress = exports.Progress = function Progress(props) {
  _checkTypes2.default.assert.maybe.number(props.min, 'Progress.props.min must be a number.');
  _checkTypes2.default.assert.maybe.number(props.max, 'Progress.props.max must be a number.');
  _checkTypes2.default.assert.maybe.number(props.value, 'Progress.props.value must be a number.');
  _checkTypes2.default.assert.maybe.string(props.color, 'Progress.props.color must be a string.');

  var _props$meter = props.meter;
  var meterProps = _props$meter === undefined ? {} : _props$meter;


  var className = (0, _classnames2.default)(props.className || 'progress', props.color);

  var omitProps = ['min', 'max', 'value', 'valueText', 'color', 'meter'];

  if (props.value) {
    meterProps.widthPercent = props.value;
  }

  return _react2.default.createElement(
    'div',
    _extends({}, (0, _lodash2.default)(props, omitProps), {
      className: className,
      role: 'progressbar',
      'aria-valuemin': props.min,
      'aria-valuemax': props.max,
      'aria-valuenow': props.value,
      'aria-valuetext': props.valueText }),
    meterProps.text ? _react2.default.createElement(ProgressMeterWithText, meterProps) : _react2.default.createElement(ProgressMeter, meterProps)
  );
};

/**
 * Progress meter sub-component.
 *
 * @param {Object} props
 * @returns {XML}
 */
var ProgressMeter = exports.ProgressMeter = function ProgressMeter(props) {
  return _react2.default.createElement('div', _extends({}, props, { className: props.className || 'progress-meter' }));
};

/**
 * Progress meter with text sub-component.
 *
 * @param {Object} props
 * @returns {XML}
 */
var ProgressMeterWithText = exports.ProgressMeterWithText = function ProgressMeterWithText(props) {
  return _react2.default.createElement(
    'span',
    _extends({}, props, { className: props.className || 'progress-meter' }),
    _react2.default.createElement(
      ProgressMeterText,
      null,
      props.text
    )
  );
};

/**
 * Progress meter text sub-component.
 *
 * @param {Object} props
 * @returns {XML}
 */
var ProgressMeterText = exports.ProgressMeterText = function ProgressMeterText(props) {
  return _react2.default.createElement('p', _extends({}, props, { className: props.className || 'progress-meter-text' }));
};

/**
 * Native progress component.
 * http://foundation.zurb.com/sites/docs/progress-bar.html#native-progress
 *
 * @param {Object} props
 * @returns {XML}
 */
var NativeProgress = exports.NativeProgress = function NativeProgress(props) {
  _checkTypes2.default.assert.maybe.number(props.max, 'ProgressBar.props.max must be a number.');
  _checkTypes2.default.assert.maybe.number(props.value, 'ProgressBar.props.value must be a number.');
  _checkTypes2.default.assert.maybe.string(props.color, 'ProgressBar.props.color must be a string.');

  var className = (0, _classnames2.default)(props.className, props.color);

  var omitProps = ['color'];

  return _react2.default.createElement('progress', _extends({}, (0, _lodash2.default)(props, omitProps), { className: className }));
};

// TODO: Consider adding support for native meter.

exports.default = Progress;