'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SwitchInactive = exports.SwitchActive = exports.SwitchPaddle = exports.SwitchInput = exports.Switch = exports.SwitchSizes = exports.SwitchTypes = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _checkTypes = require('check-types');

var _checkTypes2 = _interopRequireDefault(_checkTypes);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _lodash = require('lodash.omit');

var _lodash2 = _interopRequireDefault(_lodash);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var currentId = 0;

/**
 * Switch type enumerable.
 *
 * @type {Object}
 */
var SwitchTypes = exports.SwitchTypes = {
  CHECKBOX: 'checkbox',
  RADIO: 'radio'
};

/**
 * Switch size enumerable.
 *
 * @type {Object}
 */
var SwitchSizes = exports.SwitchSizes = {
  TINY: 'tiny',
  SMALL: 'small',
  LARGE: 'large'
};

/**
 * Switch component.
 * http://foundation.zurb.com/sites/docs/switch.html
 *
 * @param {Object} props
 * @returns {XML}
 */
var Switch = exports.Switch = function Switch(props) {
  _checkTypes2.default.assert.maybe.string(props.size, 'Switch.props.size must be a string.');
  _checkTypes2.default.assert.maybe.string(props.id, 'Switch.props.id must be a string.');

  var className = (0, _classnames2.default)(props.className || 'switch', props.size);

  var switchId = props.id || 'switch' + currentId++;
  var omitProps = ['id', 'size', 'input', 'paddle'];

  // TODO: Consider refactoring this, the rendering a little bit messy...

  return _react2.default.createElement(
    'div',
    _extends({}, (0, _lodash2.default)(props, omitProps), { className: className }),
    _react2.default.createElement(SwitchInput, _extends({}, props.input, { id: switchId })),
    _react2.default.createElement(
      SwitchPaddle,
      _extends({}, props.paddle, { htmlFor: switchId }),
      props.active ? _react2.default.createElement(SwitchActive, props.active) : null,
      props.inactive ? _react2.default.createElement(SwitchInactive, props.inactive) : null
    )
  );
};

/**
 * Switch input sub-component.
 *
 * @param {Object} props
 * @returns {XML}
 */
var SwitchInput = exports.SwitchInput = function SwitchInput(props) {
  _checkTypes2.default.assert.maybe.string(props.type, 'SwitchInput.props.type must be a string.');

  var omitProps = ['type'];

  return _react2.default.createElement('input', _extends({}, (0, _lodash2.default)(props, omitProps), { className: props.className || 'switch-input', type: props.type || SwitchTypes.CHECKBOX }));
};

/**
 * Switch paddle sub-component.
 *
 * @param {Object} props
 * @returns {XML}
 */
var SwitchPaddle = exports.SwitchPaddle = function SwitchPaddle(props) {
  return _react2.default.createElement('label', _extends({}, props, { className: props.className || 'switch-paddle' }));
};

/**
 * Switch active sub-component.
 *
 * @param {Object} props
 * @returns {XML}
 */
var SwitchActive = exports.SwitchActive = function SwitchActive(props) {
  return _react2.default.createElement(
    'span',
    _extends({}, props, { className: props.className || 'switch-active', 'aria-hidden': 'true' }),
    props.text
  );
};

/**
 * Switch inactive sub-component.
 *
 * @param {Object} props
 * @returns {XML}
 */
var SwitchInactive = exports.SwitchInactive = function SwitchInactive(props) {
  return _react2.default.createElement(
    'span',
    _extends({}, props, { className: props.className || 'switch-inactive', 'aria-hidden': 'true' }),
    props.text
  );
};

exports.default = Switch;